from django.conf import settings
from django.conf.urls import patterns, include, url

from django.contrib import admin

from django.contrib.auth.decorators import login_required
from django.views.static import serve as static_serve

from .views import APPS_PATTERNS, HomePageView, ManageView, ManageAddView
from .urls_utils import decorated_includes
from .base.urls import access_urlpatterns

import choosit.urls
import gdc.urls
import mobyt.urls
import ovh.urls
import oxyd.urls

admin.autodiscover()

urlpatterns = patterns('',
    url(r'^$', HomePageView.as_view(), name='homepage'),

    url(r'^manage/$', login_required(ManageView.as_view()), name='manage-home'),
    url(r'^manage/add$', login_required(ManageAddView.as_view()), name='add-connector'),

    url(r'^media/(?P<path>.*)$', login_required(static_serve), {
        'document_root': settings.MEDIA_ROOT,
    }),
    url(r'^admin/', include(admin.site.urls)),
    url(r'^accounts/logout/', 'django.contrib.auth.views.logout_then_login'),
    url(r'^accounts/', include('django.contrib.auth.urls')),

    url(r'^manage/access/',
        decorated_includes(login_required, include(access_urlpatterns))),

    url(r'^choosit/', include(choosit.urls.urlpatterns)),
    url(r'^manage/choosit/',
        decorated_includes(login_required, include(choosit.urls.management_urlpatterns))),

    url(r'^gdc/', include(gdc.urls.urlpatterns)),
    url(r'^manage/gdc/',
        decorated_includes(login_required, include(gdc.urls.management_urlpatterns))),

    url(r'^mobyt/', include(mobyt.urls.urlpatterns)),
    url(r'^manage/mobyt/',
        decorated_includes(login_required, include(mobyt.urls.management_urlpatterns))),

    url(r'^ovh/', include(ovh.urls.urlpatterns)),
    url(r'^manage/ovh/',
        decorated_includes(login_required, include(ovh.urls.management_urlpatterns))),

    url(r'^oxyd/', include(oxyd.urls.urlpatterns)),
    url(r'^manage/oxyd/',
        decorated_includes(login_required, include(oxyd.urls.management_urlpatterns))),
)

# activate URL for installed apps only
for app, d in APPS_PATTERNS.items():
    if 'passerelle.%s' % app in settings.INSTALLED_APPS:
        urlpatterns += patterns('',
            url(r'^%s/' % d['url'], include('passerelle.%s.urls' % app),
                {'resource_name': d['name']}),
        )

from django.contrib.staticfiles.urls import staticfiles_urlpatterns
urlpatterns += staticfiles_urlpatterns()
