from django.views.generic.base import TemplateView
from django.conf import settings
from django.db import models

from passerelle.base.models import BaseResource

APPS_PATTERNS = {
    'datasources': {'url': 'data', 'name': 'Data Sources'},
    'repost': {'url': 'repost', 'name': 'Re-Post'},
    'register': {'url': r'register', 'name': 'Register'},
    'queue': {'url': r'queue', 'name': 'Queues'},
}


class HomePageView(TemplateView):
    template_name = 'passerelle/homepage.html'

    def get_context_data(self, **kwargs):
        context = super(HomePageView, self).get_context_data(**kwargs)
        context['apps'] = []
        for app in (app for app in settings.INSTALLED_APPS if app.startswith('passerelle.')):
            app = app.split('.')[1]
            if app in APPS_PATTERNS:
                context['apps'].append(APPS_PATTERNS[app])
        return context


def get_all_apps():
    # TODO: once the legacy connectors are ported, the test on get_icon_class
    # won't be necessary anymore.
    return [x for x in models.get_models() if issubclass(x, BaseResource) and \
            hasattr(x, 'get_icon_class')]


class ManageView(TemplateView):
    template_name = 'passerelle/manage.html'

    def get_context_data(self, **kwargs):
        context = super(ManageView, self).get_context_data(**kwargs)
        # get all app instances
        context['apps'] = []
        for app in get_all_apps():
            context['apps'].extend(app.objects.all())
        return context


class ManageAddView(TemplateView):
    template_name = 'passerelle/manage_add.html'

    def get_context_data(self, **kwargs):
        context = super(ManageAddView, self).get_context_data(**kwargs)
        context['apps'] = get_all_apps()
        return context
